@@ -3,13 +3,16 @@ from typing import Optional
 import click
 import pystac
 from pystac.utils import make_absolute_href
-
 from stactools.core.copy import copy_catalog, move_all_assets
 
 
 def create_move_assets_command(cli: click.Group) -> click.Command:
     @cli.command(
-        "move-assets", short_help="Move or copy assets in a STAC to the Item locations."
+        "move-assets",
+        help=(
+            "Move or copy assets in a STAC catalog to the locations of the "
+            "items or collections that own them."
+        ),
     )
     @click.argument("catalog_path")
     @click.option("-c", "--copy", help="Copy assets instead of moving.", is_flag=True)
@@ -69,7 +72,7 @@ def create_copy_command(cli: click.Group) -> click.Command:
         "--copy-assets",
         "-a",
         is_flag=True,
-        help=("Copy all item assets to " "be alongside the new item location."),
+        help="Copy all asset files to be alongside the new location.",
     )
     @click.option(
         "-l",
@@ -79,20 +82,36 @@ def create_copy_command(cli: click.Group) -> click.Command:
             "instead of the destination folder."
         ),
     )
+    @click.option(
+        "--resolve-links/--no-resolve-links",
+        default=True,
+        help=(
+            "Whether to resolve HREF links. Defaults to --resolve-links. "
+            "Use --no-resolve-links to avoid writing external child objects locally."
+        ),
+    )
     def copy_command(
         src: str,
         dst: str,
         catalog_type: pystac.CatalogType,
         copy_assets: bool,
         publish_location: Optional[str],
+        resolve_links: bool,
     ) -> None:
-        """Copy a STAC Catalog or Collection at SRC to the directory
-        at DST.
+        """Copy a STAC Catalog or Collection at SRC to the directory at DST.
 
-        Note: Copying a catalog will upgrade it to the latest version of STAC."""
+        Note: Copying a catalog will upgrade it to the latest version of STAC.
+        """
         source_catalog = pystac.read_file(make_absolute_href(src))
         if not isinstance(source_catalog, pystac.Catalog):
             raise click.BadArgumentUsage(f"{src} is not a STAC Catalog")
-        copy_catalog(source_catalog, dst, catalog_type, copy_assets, publish_location)
+        copy_catalog(
+            source_catalog,
+            dst,
+            catalog_type,
+            copy_assets,
+            publish_location,
+            resolve_links,
+        )
 
     return copy_command
