@@ -1,15 +1,24 @@
 import json
 import sys
+from typing import List
 
 import click
-
 from stactools.core import create
 
 
 def create_create_item_command(cli: click.Group) -> click.Command:
     @cli.command("create-item", short_help="Creates an item from an asset")
     @click.argument("href")
-    def create_item_command(href: str) -> None:
+    @click.argument("asset_key", default="data")
+    @click.option(
+        "-r",
+        "--role",
+        "roles",
+        help="Optional, semantic roles of the asset",
+        multiple=True,
+        default=["data"],
+    )
+    def create_item_command(href: str, asset_key: str, roles: List[str]) -> None:
         """Creates an Item from a href.
 
         The href must be a `rasterio` readable asset. The item's dictionary will
@@ -17,7 +26,7 @@ def create_create_item_command(cli: click.Group) -> click.Command:
         If you need additional capabilities, we recommend using [rio
         stac](https://github.com/developmentseed/rio-stac/).
         """
-        item = create.item(href)
+        item = create.item(href, asset_key=asset_key, roles=roles)
         json.dump(item.to_dict(), sys.stdout)
 
     return create_item_command
