@@ -1,27 +1,32 @@
 from stactools.core.add import add_item
-from stactools.core.add_asset import add_asset_to_item
+from stactools.core.add_asset import add_asset, add_asset_to_item
 from stactools.core.add_raster import add_raster_to_item
 from stactools.core.copy import (
     copy_catalog,
     move_all_assets,
+    move_asset_file,
     move_asset_file_to_item,
     move_assets,
 )
 from stactools.core.io import use_fsspec
 from stactools.core.layout import layout_catalog
 from stactools.core.merge import merge_all_items, merge_items
+from stactools.core.migrate import migrate_object
 
 __all__ = [
     "add_item",
+    "add_asset",
     "add_asset_to_item",
     "add_raster_to_item",
     "copy_catalog",
     "layout_catalog",
     "merge_all_items",
     "merge_items",
+    "migrate_object",
+    "move_asset_file",
     "move_asset_file_to_item",
     "move_assets",
     "move_all_assets",
     "use_fsspec",
 ]
-__version__ = "0.4.4"
+__version__ = "0.5.3"
