@@ -1,18 +1,23 @@
 import datetime
 import os.path
-from typing import Optional
+from typing import List, Optional
 
 import rasterio
 import shapely.geometry
+import stactools.core.projection
 from pystac import Asset, Item
 from pystac.extensions.projection import ProjectionExtension
 
-import stactools.core.projection
-
 from .io import ReadHrefModifier
 
 
-def item(href: str, read_href_modifier: Optional[ReadHrefModifier] = None) -> Item:
+def item(
+    href: str,
+    *,
+    asset_key: str = "data",
+    roles: List[str] = ["data"],
+    read_href_modifier: Optional[ReadHrefModifier] = None,
+) -> Item:
     """Creates a STAC Item from the asset at the provided href.
 
     The ``read_href_modifer`` argument can be used to modify the href for the
@@ -23,6 +28,8 @@ def item(href: str, read_href_modifier: Optional[ReadHrefModifier] = None) -> It
 
     Args:
         href (str): The href of the asset that will be used to create the item.
+        asset_key (str): The unique key of the asset
+        roles (List[str]): The semantic roles of the asset
         read_href_modifier (Optional[ReadHrefModifier]):
             An optional callable that will be used to modify the href before reading.
 
@@ -39,14 +46,14 @@ def item(href: str, read_href_modifier: Optional[ReadHrefModifier] = None) -> It
         proj_bbox = dataset.bounds
         proj_transform = list(dataset.transform)[0:6]
         proj_shape = dataset.shape
-    proj_geometry = shapely.geometry.mapping(shapely.geometry.box(*proj_bbox))
-    geometry = stactools.core.projection.reproject_geom(
-        crs, "EPSG:4326", proj_geometry, precision=6
+    geom = stactools.core.projection.reproject_shape(
+        crs, "EPSG:4326", shapely.geometry.box(*proj_bbox), precision=6
     )
-    bbox = list(shapely.geometry.shape(geometry).bounds)
+    bbox = list(geom.bounds)
+    geojson = shapely.geometry.mapping(geom)
     item = Item(
         id=id,
-        geometry=geometry,
+        geometry=geojson,
         bbox=bbox,
         datetime=datetime.datetime.now(),
         properties={},
@@ -61,6 +68,6 @@ def item(href: str, read_href_modifier: Optional[ReadHrefModifier] = None) -> It
     projection.transform = proj_transform
     projection.shape = proj_shape
 
-    item.add_asset("data", Asset(href=href, roles=["data"]))
+    item.add_asset(asset_key, Asset(href=href, roles=roles))
 
     return item
