@@ -5,8 +5,7 @@ import pystac
 from pystac.layout import BestPracticesLayoutStrategy
 from pystac.utils import is_absolute_href, make_relative_href
 from shapely.geometry import mapping, shape
-
-from stactools.core.copy import copy_catalog, move_asset_file_to_item
+from stactools.core.copy import copy_catalog, move_asset_file
 from stactools.core.copy import move_assets as do_move_assets
 
 
@@ -52,7 +51,7 @@ def merge_items(
             if asset_href is None:
                 raise ValueError(f"Asset {asset.title} must have an HREF for merge")
             if move_assets:
-                new_asset_href = move_asset_file_to_item(
+                new_asset_href = move_asset_file(
                     target_item, asset_href, ignore_conflicts=ignore_conflicts
                 )
             else:
@@ -109,7 +108,7 @@ def merge_all_items(
     Returns:
         pystac.Catalog or pystac.Collection: The ``target_catalog``
     """
-    source_items = source_catalog.get_all_items()
+    source_items = source_catalog.get_items(recursive=True)
     ids_to_items = {item.id: item for item in source_items}
 
     parent_dir = os.path.dirname(target_catalog.self_href)
@@ -129,7 +128,7 @@ def merge_all_items(
         source_catalog = new_source_catalog
         target_catalog.add_child(source_catalog, source_catalog.title)
     else:
-        for item in target_catalog.get_all_items():
+        for item in target_catalog.get_items(recursive=True):
             source_item = ids_to_items.get(item.id)
             if source_item is not None:
                 merge_items(
