@@ -1,8 +1,9 @@
-"""Generate convex hulls of valid raster data for use in STAC Item geometries."""
+"""Generate convex hulls of valid raster data for use in STAC Item
+geometries."""
 
 import logging
 import warnings
-from itertools import groupby
+from enum import Enum, auto
 from typing import Any, Dict, Iterator, List, Optional, Tuple, Type, TypeVar, Union
 
 import numpy as np
@@ -12,10 +13,13 @@ import rasterio.features
 from pystac import Item
 from rasterio import Affine, DatasetReader
 from rasterio.crs import CRS
-from rasterio.warp import transform_geom
 from shapely.geometry import mapping, shape
 from shapely.geometry.multipolygon import MultiPolygon
-from shapely.geometry.polygon import Polygon
+from shapely.geometry.polygon import Polygon, orient
+from shapely.ops import unary_union
+from stactools.core.geometry import mutual_intersection
+
+from ..projection import reproject_shape
 
 logger = logging.getLogger(__name__)
 
@@ -25,16 +29,28 @@ DEFAULT_PRECISION = 7
 T = TypeVar("T", bound="RasterFootprint")
 
 
+class FootprintMergeStrategy(Enum):
+    """Strategy for handling the aggregation of differing asset footprints."""
+
+    FIRST = auto()
+    """Use the footprint of the first matching asset."""
+
+    UNION = auto()
+    """Union the geometries of all matching assets."""
+
+    INTERSECTION = auto()
+    """Use the mutual intersection of all matching asset footprints."""
+
+
 def densify_by_factor(
     point_list: List[Tuple[float, float]], factor: int
 ) -> List[Tuple[float, float]]:
-    """
-    Densifies the number of points in a list of points by a ``factor``. For
+    """Densifies the number of points in a list of points by a ``factor``. For
     example, a list of 5 points and a factor of 2 will result in 10 points (one
     new point between each original adjacent points).
 
     Derived from code found at
-    https://stackoverflow.com/questions/64995977/generating-equidistance-points-along-the-boundary-of-a-polygon-but-cw-ccw  # noqa
+    https://stackoverflow.com/questions/64995977/generating-equidistance-points-along-the-boundary-of-a-polygon-but-cw-ccw
 
     Args:
         point_list (List[Tuple[float, float]]): The list of points to be
@@ -45,29 +61,27 @@ def densify_by_factor(
 
     Returns:
         List[Tuple[float, float]]: A list of the densified points.
-    """
+    """  # noqa: E501
     points: Any = np.asarray(point_list)
     densified_number = len(points) * factor
     existing_indices = np.arange(0, densified_number, factor)
-    interp_indices = np.arange(existing_indices[-1])
+    interp_indices = np.arange(existing_indices[-1] + 1)
     interp_x = np.interp(interp_indices, existing_indices, points[:, 0])
     interp_y = np.interp(interp_indices, existing_indices, points[:, 1])
-    densified_points = [(x, y) for x, y in zip(interp_x, interp_y)]
-    return densified_points
+    return [(x, y) for x, y in zip(interp_x, interp_y)]
 
 
 def densify_by_distance(
     point_list: List[Tuple[float, float]], distance: float
 ) -> List[Tuple[float, float]]:
-    """
-    Densifies the number of points in a list of points by inserting new
+    """Densifies the number of points in a list of points by inserting new
     points at intervals between each set of successive points. For example, if
     two successive points in the list are separated by 10 units and a
     ``distance`` of 2 is provided, 4 new points will be added between the two
     original points (one new point every 2 units of ``distance``).
 
     Derived from code found at
-    https://stackoverflow.com/questions/64995977/generating-equidistance-points-along-the-boundary-of-a-polygon-but-cw-ccw # noqa
+    https://stackoverflow.com/questions/64995977/generating-equidistance-points-along-the-boundary-of-a-polygon-but-cw-ccw
 
     Args:
         point_list (List[Tuple[float, float]]): The list of points to be
@@ -82,21 +96,31 @@ def densify_by_distance(
     points: Any = np.asarray(point_list)
     dxdy = points[1:, :] - points[:-1, :]
     segment_lengths = np.sqrt(np.sum(np.square(dxdy), axis=1))
-    total_length = np.sum(segment_lengths)
-    cum_segment_lengths = np.cumsum(segment_lengths)
-    cum_segment_lengths = np.insert(cum_segment_lengths, 0, [0])
-    cum_interp_lengths = np.arange(0, total_length, distance)
-    cum_interp_lengths = np.append(cum_interp_lengths, [total_length])
-    interp_x = np.interp(cum_interp_lengths, cum_segment_lengths, points[:, 0])
-    interp_y = np.interp(cum_interp_lengths, cum_segment_lengths, points[:, 1])
-    return [(x, y) for x, y in zip(interp_x, interp_y)]
+    steps = segment_lengths / distance
+    coordinate_steps = dxdy / steps.reshape(-1, 1)
+    densified_points = np.empty((len(point_list) - 1,), dtype="O")
+    for index in range(len(point_list) - 1):
+        step = np.arange(steps[index])
+        densified_points[index] = (
+            np.array((step, step)).T * coordinate_steps[index] + points[index]
+        )
+    final_point = points[-1].reshape(1, -1)
+    densified_array = np.concatenate((*densified_points, final_point), axis=0)
+    return [(float(row[0]), float(row[1])) for row in densified_array]
 
 
 def reproject_polygon(
-    polygon: Polygon, crs: CRS, precision: Optional[int] = DEFAULT_PRECISION
+    polygon: Polygon,
+    crs: CRS,
+    precision: Optional[int] = DEFAULT_PRECISION,
+    dst_crs: CRS = "EPSG:4326",
 ) -> Polygon:
-    """Projects a polygon to EPSG 4326 and rounds the projected vertex
-    coordinates to ``precision``.
+    """DEPRECATED.
+
+    .. deprecated:: 0.5.0
+        Use :func:`projection.reproject_shape` instead.
+
+    Projects a polygon and rounds the projected vertex coordinates to ``precision``.
 
     Duplicate points caused by rounding are removed.
 
@@ -105,16 +129,19 @@ def reproject_polygon(
         crs (CRS): The CRS of the input polygon.
         precision (int): The number of decimal places to include in the final
             polygon vertex coordinates.
+        dst_crs (CRS): The CRS of the output polygon. Defaults to EPSG 4326
 
     Returns:
-        Polygon: Polygon in EPSG 4326.
+        Polygon: Polygon in 'dst_crs'. Default to EPSG 4326
     """
-    polygon = shape(transform_geom(crs, "EPSG:4326", polygon, precision=precision))
-    # Rounding to precision can produce duplicate coordinates, so we remove
-    # them. Once once shapely>=2.0.0 is required, this can be replaced with
-    # shapely.constructive.remove_repeated_points
-    polygon = Polygon([k for k, _ in groupby(polygon.exterior.coords)])
-    return polygon
+    warnings.warn(
+        "``utils.reproject_polygon`` is deprecated and will be removed in v0.6.0. "
+        "Use ``projection.reproject_shape`` instead.",
+        DeprecationWarning,
+    )
+    return reproject_shape(
+        src_crs=crs, dst_crs=dst_crs, geom=polygon, precision=precision
+    )
 
 
 class RasterFootprint:
@@ -126,7 +153,7 @@ class RasterFootprint:
 
     Two important operations during this calculation are the densification of
     the footprint in the native CRS and simplification of the footprint after
-    reprojection to EPSG 4326. If the initial low-vertex polygon in the native
+    reprojection. If the initial low-vertex polygon in the native
     CRS is not densified, this can result in a reprojected polygon that does not
     accurately represent the data footprint. For example, a MODIS asset
     represented by a rectangular 5 point Polygon in a sinusoidal projection will
@@ -135,7 +162,7 @@ class RasterFootprint:
     difference between these representations is greater the further away from
     the meridian and equator the asset is located.
 
-    After reprojection to EPSG 4326, the footprint may have more points than
+    After reprojection, the footprint may have more points than
     desired. This can be simplified to a polygon with fewer points that maintain
     a maximum distance to the original geometry.
 
@@ -143,13 +170,15 @@ class RasterFootprint:
         data_array (numpy.NDArray[Any]): The raster data used for the
             footprint calculation.
         crs (CRS): Coordinate reference system of the raster data.
+        dst_crs (CRS): Coordinate reference system of the footprint data. Defaults
+            to EPSG 4236.
         transform (Affine): Matrix defining the transformation from pixel to CRS
             coordinates.
         precision (int): The number of decimal places to include in the
             final footprint coordinates.
         densification_factor (Optional[int]): The factor by which to
             increase point density within the footprint polygon before
-            projection to EPSG 4326. A factor of 2 would double the density of
+            projection. A factor of 2 would double the density of
             points (placing one new point between each existing pair of points),
             a factor of 3 would place two points between each point, etc. Higher
             densities produce higher fidelity footprints in areas of high
@@ -157,13 +186,13 @@ class RasterFootprint:
             ``densification_distance``.
         densification_distance (Optional[float]): The distance by which to
             increase point density within the footprint polygon before
-            projection to EPSG 4326. If the distance is set to 2 and the segment
+            projection. If the distance is set to 2 and the segment
             length between two polygon vertices is 10, 4 new vertices would be
             created along the segment. Higher densities produce higher
             fidelity footprints in areas of high projection distortion.
             Mutually exclusive with ``densification_factor``.
-        simplify_tolerance (Optional[float]): Distance, in degrees, within which
-            all locations on the simplified polygon will be to the original
+        simplify_tolerance (Optional[float]): Distance, in degrees, within
+            which all locations on the simplified polygon will be to the original
             polygon.
         no_data (Optional[Union[int, float]]): The nodata value in
             ``data_array``. If set to None, this will return a footprint
@@ -173,14 +202,17 @@ class RasterFootprint:
     crs: CRS
     """Coordinate reference system of the raster data."""
 
+    dst_crs: CRS = "EPSG:4326"
+    """Coordinate reference system of the footprint."""
+
     data_array: npt.NDArray[Any]
     """2D or 3D array of raster data."""
 
     densification_distance: Optional[float]
-    """Optional distance for densifying polygon vertices before reprojection to EPSG 4326."""
+    """Optional distance for densifying polygon vertices before reprojection."""
 
     densification_factor: Optional[int]
-    """Optional factor for densifying polygon vertices before reprojection to EPSG 4326."""
+    """Optional factor for densifying polygon vertices before reprojection."""
 
     no_data: Optional[Union[int, float]]
     """Optional value defining pixels to exclude from the footprint."""
@@ -189,7 +221,8 @@ class RasterFootprint:
     """Number of decimal places in the final footprint coordinates."""
 
     simplify_tolerance: Optional[float]
-    """Optional maximum allowable error when simplifying the reprojected polygon."""
+    """Optional maximum allowable error when simplifying the reprojected
+    polygon."""
 
     transform: Affine
     """Transformation matrix from pixel to CRS coordinates."""
@@ -200,6 +233,7 @@ class RasterFootprint:
         crs: CRS,
         transform: Affine,
         *,
+        dst_crs: CRS = "EPSG:4326",
         precision: int = DEFAULT_PRECISION,
         densification_factor: Optional[int] = None,
         densification_distance: Optional[float] = None,
@@ -210,6 +244,7 @@ class RasterFootprint:
             data_array = data_array[np.newaxis, :]
         self.data_array = data_array
         self.crs = crs
+        self.dst_crs = dst_crs
         self.transform = transform
         self.precision = precision
         if densification_factor is not None and densification_distance is not None:
@@ -223,9 +258,9 @@ class RasterFootprint:
         self.no_data = no_data
 
     def footprint(self) -> Optional[Dict[str, Any]]:
-        """Produces the footprint surrounding data (not nodata) pixels in
-        the source image. If the footprint is unable to be computed, None
-        is returned.
+        """Produces the footprint surrounding data (not nodata) pixels in the
+        source image. If the footprint is unable to be computed, None is
+        returned.
 
         Returns:
             Optional[Dict[str, Any]]: A GeoJSON dictionary containing the
@@ -247,7 +282,6 @@ class RasterFootprint:
         Returns:
             numpy.NDArray[numpy.uint8]: A 2D array containing 0s and 1s for
             nodata/data pixels.
-
         """
         assert self.data_array.ndim == 3
         shape = self.data_array.shape
@@ -256,7 +290,7 @@ class RasterFootprint:
             if np.isnan(self.no_data):
                 mask[~np.isnan(self.data_array)] = 1
             else:
-                mask[np.where(self.data_array != self.no_data)] = 1
+                mask[self.data_array != self.no_data] = 1
             mask = np.sum(mask, axis=0, dtype=np.uint8)
             mask[mask > 0] = 1
         else:
@@ -289,11 +323,12 @@ class RasterFootprint:
         else:
             polygon = MultiPolygon(data_polygons).convex_hull
 
-        return polygon
+        return orient(polygon)
 
     def densify_polygon(self, polygon: Polygon) -> Polygon:
-        """Adds vertices to the footprint polygon in the native CRS using either
-        ``self.densification_factor`` or ``self.densification_distance``.
+        """Adds vertices to the footprint polygon in the native CRS using
+        either ``self.densification_factor`` or
+        ``self.densification_distance``.
 
         Args:
             polygon (Polygon): Footprint polygon in the native CRS.
@@ -316,8 +351,8 @@ class RasterFootprint:
             return polygon
 
     def reproject_polygon(self, polygon: Polygon) -> Polygon:
-        """Projects a polygon to EPSG 4326 and rounds the projected vertex
-        coordinates to ``self.precision``.
+        """Projects a polygon and rounds the projected vertex coordinates to
+        ``self.precision``.
 
         Duplicate points caused by rounding are removed.
 
@@ -325,14 +360,19 @@ class RasterFootprint:
             polygon (Polygon): Footprint polygon in the native CRS.
 
         Returns:
-            Polygon: Footprint polygon in EPSG 4326.
+            Polygon: Footprint polygon in 'dst_crs'.
         """
-        return reproject_polygon(polygon, self.crs, self.precision)
+        return reproject_shape(
+            src_crs=self.crs,
+            dst_crs=self.dst_crs,
+            geom=polygon,
+            precision=self.precision,
+        )
 
     def simplify_polygon(self, polygon: Polygon) -> Polygon:
         """Reduces the number of polygon vertices such that the simplified
-        polygon shape is no further away than the original polygon vertices than
-        ``self.simplify_tolerance``.
+        polygon shape is no further away than the original polygon vertices
+        than ``self.simplify_tolerance``.
 
         Args:
             polygon (Polygon): Polygon to be simplified.
@@ -341,8 +381,10 @@ class RasterFootprint:
             Polygon: Reduced vertex polygon.
         """
         if self.simplify_tolerance is not None:
-            return polygon.simplify(
-                tolerance=self.simplify_tolerance, preserve_topology=False
+            return orient(
+                polygon.simplify(
+                    tolerance=self.simplify_tolerance, preserve_topology=False
+                )
             )
         return polygon
 
@@ -351,6 +393,7 @@ class RasterFootprint:
         cls: Type[T],
         href: str,
         *,
+        dst_crs: CRS = "EPSG:4326",
         precision: int = DEFAULT_PRECISION,
         densification_factor: Optional[int] = None,
         densification_distance: Optional[float] = None,
@@ -364,11 +407,13 @@ class RasterFootprint:
 
         Args:
             href (str): The href of the image to process.
+            dst_crs (CRS): Coordinate reference system of the footprint data. Defaults
+                to EPSG 4236.
             precision (int): The number of decimal places to include in the
                 final footprint coordinates.
             densification_factor (Optional[int]): The factor by which to
                 increase point density within the footprint polygon before
-                projection to EPSG 4326. A factor of 2 would double the density
+                projection. A factor of 2 would double the density
                 of points (placing one new point between each existing pair of
                 points), a factor of 3 would place two points between each point,
                 etc. Higher densities produce higher fidelity footprints in
@@ -376,7 +421,7 @@ class RasterFootprint:
                 ``densification_distance``.
             densification_distance (Optional[float]): The distance by which to
                 increase point density within the footprint polygon before
-                projection to EPSG 4326. If the distance is set to 2 and the
+                projection. If the distance is set to 2 and the
                 segment length between two polygon vertices is 10, 4 new
                 vertices would be created along the segment. Higher densities
                 produce higher fidelity footprints in areas of high projection
@@ -398,6 +443,7 @@ class RasterFootprint:
         with rasterio.open(href) as source:
             return cls.from_rasterio_dataset_reader(
                 reader=source,
+                dst_crs=dst_crs,
                 no_data=no_data,
                 bands=bands,
                 precision=precision,
@@ -411,6 +457,7 @@ class RasterFootprint:
         cls: Type[T],
         reader: DatasetReader,
         *,
+        dst_crs: CRS = "EPSG:4326",
         precision: int = DEFAULT_PRECISION,
         densification_factor: Optional[int] = None,
         densification_distance: Optional[float] = None,
@@ -425,11 +472,13 @@ class RasterFootprint:
         Args:
             reader (DatasetReader): A rasterio dataset reader object for the
                 image to process.
+            dst_crs (CRS): Coordinate reference system of the footprint data. Defaults
+                to EPSG 4236.
             precision (int): The number of decimal places to include in the
                 final footprint coordinates.
             densification_factor (Optional[int]): The factor by which to
                 increase point density within the footprint polygon before
-                projection to EPSG 4326. A factor of 2 would double the density
+                projection. A factor of 2 would double the density
                 of points (placing one new point between each existing pair of
                 points), a factor of 3 would place two points between each point,
                 etc. Higher densities produce higher fidelity footprints in
@@ -437,7 +486,7 @@ class RasterFootprint:
                 ``densification_distance``.
             densification_distance (Optional[float]): The distance by which to
                 increase point density within the footprint polygon before
-                projection to EPSG 4326. If the distance is set to 2 and the
+                projection. If the distance is set to 2 and the
                 segment length between two polygon vertices is 10, 4 new
                 vertices would be created along the segment. Higher densities
                 produce higher fidelity footprints in areas of high projection
@@ -475,6 +524,7 @@ class RasterFootprint:
         return cls(
             data_array=np.asarray(band_data),
             crs=reader.crs,
+            dst_crs=dst_crs,
             transform=reader.transform,
             no_data=no_data,
             precision=precision,
@@ -489,6 +539,7 @@ class RasterFootprint:
         item: Item,
         *,
         asset_names: List[str] = [],
+        dst_crs: CRS = "EPSG:4326",
         precision: int = DEFAULT_PRECISION,
         densification_factor: Optional[int] = None,
         densification_distance: Optional[float] = None,
@@ -496,11 +547,13 @@ class RasterFootprint:
         no_data: Optional[Union[int, float]] = None,
         bands: List[int] = [1],
         skip_errors: bool = True,
+        footprint_merge_strategy: FootprintMergeStrategy = FootprintMergeStrategy.FIRST,
     ) -> bool:
-        """
-        Accepts an Item and an optional list of asset names within that Item, and
-        updates the geometry of that Item in-place with the data footprint derived
-        from the first of the assets that exists in the Item.
+        """Accepts an Item and an optional list of asset names within that
+        Item, and updates the geometry of that Item in-place with the data
+        footprint derived from the first of the assets that exists in the Item.
+        The Item bbox is also updated in-place to bound the new footprint
+        extents.
 
         See :class:`RasterFootprint` for details on the data footprint
         calculation.
@@ -510,11 +563,13 @@ class RasterFootprint:
             asset_names (List[str]): The names of the assets for which to attempt to
                 extract footprints. The first successful footprint will be used. If
                 the list is empty, all assets will be tried until one is successful.
+            dst_crs (CRS): Coordinate reference system of the footprint data. Defaults
+                to EPSG 4236.
             precision (int): The number of decimal places to include in the final
                 footprint coordinates.
             densification_factor (Optional[int]): The factor by which to
                 increase point density within the footprint polygon before
-                projection to EPSG 4326. A factor of 2 would double the density
+                projection. A factor of 2 would double the density
                 of points (placing one new point between each existing pair of
                 points), a factor of 3 would place two points between each point,
                 etc. Higher densities produce higher fidelity footprints in
@@ -522,7 +577,7 @@ class RasterFootprint:
                 ``densification_distance``.
             densification_distance (Optional[float]): The distance by which to
                 increase point density within the footprint polygon before
-                projection to EPSG 4326. If the distance is set to 2 and the
+                projection. If the distance is set to 2 and the
                 segment length between two polygon vertices is 10, 4 new
                 vertices would be created along the segment. Higher densities
                 produce higher fidelity footprints in areas of high projection
@@ -539,30 +594,47 @@ class RasterFootprint:
                 bands must have nodata in that pixel.
             skip_errors (bool): If False, raise an error for a missing href or
                 footprint calculation failure.
+            footprint_aggregator (FootprintMergeStrategy): Provides a
+                means to control how the footprints of assets are aggregated;
+                see :class:`FootprintMergeStrategy` for details; defaults to using
+                the `FIRST` strategy
 
         Returns:
             bool: True if the Item geometry was successfully updated, False if not.
         """
-        asset_name_and_extent = next(
-            cls.data_footprints_for_data_assets(
-                item,
-                asset_names=asset_names,
-                precision=precision,
-                densification_factor=densification_factor,
-                densification_distance=densification_distance,
-                simplify_tolerance=simplify_tolerance,
-                no_data=no_data,
-                bands=bands,
-                skip_errors=skip_errors,
-            ),
-            None,
+        asset_extent_iterator = cls.data_footprints_for_data_assets(
+            item,
+            asset_names=asset_names,
+            dst_crs=dst_crs,
+            precision=precision,
+            densification_factor=densification_factor,
+            densification_distance=densification_distance,
+            simplify_tolerance=simplify_tolerance,
+            no_data=no_data,
+            bands=bands,
+            skip_errors=skip_errors,
         )
-        if asset_name_and_extent is not None:
-            _, extent = asset_name_and_extent
-            item.geometry = extent
-            return True
+
+        if footprint_merge_strategy == FootprintMergeStrategy.FIRST:
+            asset_name_extent = next(asset_extent_iterator, None)
+            if asset_name_extent is None:
+                return False
+            _, extent = asset_name_extent
         else:
-            return False
+            extents = [shape(extent) for _, extent in asset_extent_iterator]
+            if extents == []:
+                return False
+            if footprint_merge_strategy == FootprintMergeStrategy.INTERSECTION:
+                extent = mutual_intersection(extents)
+            elif footprint_merge_strategy == FootprintMergeStrategy.UNION:
+                extent = unary_union(extents)
+            else:
+                raise Exception(
+                    f"Unrecognized aggregation strategy: {footprint_merge_strategy}"
+                )
+        item.geometry = extent
+        item.bbox = list(shape(extent).bounds)
+        return True
 
     @classmethod
     def data_footprints_for_data_assets(
@@ -570,6 +642,7 @@ class RasterFootprint:
         item: Item,
         *,
         asset_names: List[str] = [],
+        dst_crs: CRS = "EPSG:4326",
         precision: int = DEFAULT_PRECISION,
         densification_factor: Optional[int] = None,
         densification_distance: Optional[float] = None,
@@ -578,11 +651,10 @@ class RasterFootprint:
         bands: List[int] = [1],
         skip_errors: bool = True,
     ) -> Iterator[Tuple[str, Dict[str, Any]]]:
-        """
-        Accepts an Item and an optional list of asset names within that Item, and
-        produces an iterator over the same asset names (if they exist) and
-        dictionaries representing GeoJSON Polygons of the data footprints of the
-        assets.
+        """Accepts an Item and an optional list of asset names within that
+        Item, and produces an iterator over the same asset names (if they
+        exist) and dictionaries representing GeoJSON Polygons of the data
+        footprints of the assets.
 
         See :class:`RasterFootprint` for details on the data footprint
         calculation.
@@ -592,11 +664,13 @@ class RasterFootprint:
             asset_names (List[str]): The names of the assets for which to attempt to
                 extract footprints. The first successful footprint will be used. If
                 the list is empty, all assets will be tried until one is successful.
+            dst_crs (CRS): Coordinate reference system of the footprint data. Defaults
+                to EPSG 4236.
             precision (int): The number of decimal places to include in the final
                 footprint coordinates.
             densification_factor (Optional[int]): The factor by which to
                 increase point density within the footprint polygon before
-                projection to EPSG 4326. A factor of 2 would double the density
+                projection. A factor of 2 would double the density
                 of points (placing one new point between each existing pair of
                 points), a factor of 3 would place two points between each point,
                 etc. Higher densities produce higher fidelity footprints in
@@ -604,7 +678,7 @@ class RasterFootprint:
                 ``densification_distance``.
             densification_distance (Optional[float]): The distance by which to
                 increase point density within the footprint polygon before
-                projection to EPSG 4326. If the distance is set to 2 and the
+                projection. If the distance is set to 2 and the
                 segment length between two polygon vertices is 10, 4 new
                 vertices would be created along the segment. Higher densities
                 produce higher fidelity footprints in areas of high projection
@@ -644,6 +718,7 @@ class RasterFootprint:
                 else:
                     extent = cls.from_href(
                         href=href,
+                        dst_crs=dst_crs,
                         no_data=no_data,
                         bands=bands,
                         precision=precision,
@@ -676,7 +751,8 @@ def update_geometry_from_asset_footprint(
 
     Accepts an Item and an optional list of asset names within that Item, and
     updates the geometry of that Item in-place with the data footprint derived
-    from the first of the assets that exists in the Item.
+    from the first of the assets that exists in the Item. The Item bbox is also
+    updated in-place to bound the new footprint extents.
 
     See :class:`RasterFootprint` for details on the data footprint
     calculation.
@@ -868,13 +944,13 @@ def densify_reproject_simplify(
     polygon: Polygon,
     crs: CRS,
     *,
+    dst_crs: CRS = "EPSG:4326",
     densification_factor: Optional[int] = None,
     precision: int = DEFAULT_PRECISION,
     simplify_tolerance: Optional[float] = None,
 ) -> Polygon:
-    """
-    Densifies the input polygon, reprojects it to EPSG 4326, and simplifies the
-    resulting polygon.
+    """Densifies the input polygon, reprojects it, and simplifies
+    the resulting polygon.
 
     See :class:`RasterFootprint` for details on densification and
     simplification.
@@ -882,9 +958,10 @@ def densify_reproject_simplify(
     Args:
         polygon (Polygon): The input polygon.
         crs (CRS): The CRS of the input polygon.
+        dst_crs (CRS): The CRS of the output polygon. Defaults to EPSG 4326
         densification_factor (Optional[int]): The factor by which to
-            increase point density within the polygon before projection to
-            EPSG 4326. A factor of 2 would double the density of points (placing
+            increase point density within the polygon before projection.
+            A factor of 2 would double the density of points (placing
             one new point between each existing pair of points), a factor of
             3 would place two points between each point, etc. Higher
             densities produce higher fidelity footprints in areas of high
@@ -902,7 +979,9 @@ def densify_reproject_simplify(
         polygon = Polygon(
             densify_by_factor(polygon.exterior.coords, factor=densification_factor)
         )
-    polygon = reproject_polygon(polygon, crs, precision)
+    polygon = reproject_shape(
+        geom=polygon, src_crs=crs, dst_crs=dst_crs, precision=precision
+    )
     if simplify_tolerance is not None:
         polygon = polygon.simplify(
             tolerance=simplify_tolerance, preserve_topology=False
